/* Conversion of files between different charsets and surfaces.
   Copyright © 2008-2023 Free Software Foundation, Inc.
   Contributed by François Pinard <pinard@iro.umontreal.ca>, 2008.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License
   as published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   This library is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied warranty
   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Recode Library; see the file `COPYING.LIB'.
   If not, see <https://www.gnu.org/licenses/>.
*/

/* Definitions to clean up the linker namespace.  */

#ifndef CLEANER_H_
# define CLEANER_H_

# define delmodule_african librecode_delmodule_african
# define delmodule_afrtran librecode_delmodule_afrtran
# define delmodule_applemac librecode_delmodule_applemac
# define delmodule_ascii_latin1 librecode_delmodule_ascii_latin1
# define delmodule_atarist librecode_delmodule_atarist
# define delmodule_bangbang librecode_delmodule_bangbang
# define delmodule_base64 librecode_delmodule_base64
# define delmodule_cdcnos librecode_delmodule_cdcnos
# define delmodule_dump librecode_delmodule_dump
# define delmodule_ebcdic librecode_delmodule_ebcdic
# define delmodule_endline librecode_delmodule_endline
# define delmodule_flat librecode_delmodule_flat
# define delmodule_html librecode_delmodule_html
# define delmodule_ibmpc librecode_delmodule_ibmpc
# define delmodule_iconqnx librecode_delmodule_iconqnx
# define delmodule_iconv librecode_delmodule_iconv
# define delmodule_latex_latin1 librecode_delmodule_latex_latin1
# define delmodule_latin1_ascii librecode_delmodule_latin1_ascii
# define delmodule_latin1_latex librecode_delmodule_latin1_latex
# define delmodule_latin1_texte librecode_delmodule_latin1_texte
# define delmodule_mule librecode_delmodule_mule
# define delmodule_permutations librecode_delmodule_permutations
# define delmodule_quoted_printable librecode_delmodule_quoted_printable
# define delmodule_rfc1345 librecode_delmodule_rfc1345
# define delmodule_strips librecode_delmodule_strips
# define delmodule_testdump librecode_delmodule_testdump
# define delmodule_texinfo librecode_delmodule_texinfo
# define delmodule_texte_latin1 librecode_delmodule_texte_latin1
# define delmodule_ucs librecode_delmodule_ucs
# define delmodule_utf16 librecode_delmodule_utf16
# define delmodule_utf7 librecode_delmodule_utf7
# define delmodule_utf8 librecode_delmodule_utf8
# define delmodule_varia librecode_delmodule_varia
# define delmodule_vietnamese librecode_delmodule_vietnamese
# define module_african librecode_module_african
# define module_afrtran librecode_module_afrtran
# define module_applemac librecode_module_applemac
# define module_ascii_latin1 librecode_module_ascii_latin1
# define module_atarist librecode_module_atarist
# define module_bangbang librecode_module_bangbang
# define module_base64 librecode_module_base64
# define module_cdcnos librecode_module_cdcnos
# define module_dump librecode_module_dump
# define module_ebcdic librecode_module_ebcdic
# define module_endline librecode_module_endline
# define module_flat librecode_module_flat
# define module_html librecode_module_html
# define module_ibmpc librecode_module_ibmpc
# define module_iconqnx librecode_module_iconqnx
# define module_iconv librecode_module_iconv
# define module_latex_latin1 librecode_module_latex_latin1
# define module_latin1_ascii librecode_module_latin1_ascii
# define module_latin1_latex librecode_module_latin1_latex
# define module_latin1_texte librecode_module_latin1_texte
# define module_mule librecode_module_mule
# define module_permutations librecode_module_permutations
# define module_quoted_printable librecode_module_quoted_printable
# define module_rfc1345 librecode_module_rfc1345
# define module_strips librecode_module_strips
# define module_testdump librecode_module_testdump
# define module_texinfo librecode_module_texinfo
# define module_texte_latin1 librecode_module_texte_latin1
# define module_ucs librecode_module_ucs
# define module_utf16 librecode_module_utf16
# define module_utf7 librecode_module_utf7
# define module_utf8 librecode_module_utf8
# define module_varia librecode_module_varia
# define module_vietnamese librecode_module_vietnamese
# define texte_latin1_diaeresis librecode_texte_latin1_diaeresis

#endif /* ! CLEANER_H_ */
